@@ -120,35 +120,9 @@ class Levenberg_Marquart():
          return self.current_estimate
 
 
-class example():
 
-    def forward_model(self, x):
-        y = np.array(x[0] ** 2 + x[1] ** 2)
-        y = y.reshape((1, 1))
-        return y
 
-    def compute_gradient(self, x):
-        y = np.array(([2 * x[0]], [2 * x[1]]))
-        y = y.reshape((2, 1))
-        return y
 
-    def compute_hessian(self, x):
-        y = np.array(([2, 0], [0, 2]))
-        y = y.reshape((2, 2))
-        return y
-
-    def find_minimum(self):
-        initial_prediction = np.array([5, 2.7])
-
-        LM_algorithm = TRA.Levenberg_Marquart(initial_prediction, self.compute_hessian, self.compute_gradient,
-                                                  self.forward_model, d_param=1e-50,
-                                                  lower_constraint=-np.inf,
-                                                  upper_constraint=np.inf,
-                                                  num_iterations=5)
-
-        minimum = LM_algorithm.optimisation_main()
-
-        return minimum
 
 
 
